# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/visibility.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/api/visibility.proto",
    package="google.api",
    syntax="proto3",
    serialized_options=b"\n\016com.google.apiB\017VisibilityProtoP\001Z?google.golang.org/genproto/googleapis/api/visibility;visibility\370\001\001\242\002\004GAPI",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x1bgoogle/api/visibility.proto\x12\ngoogle.api\x1a google/protobuf/descriptor.proto"7\n\nVisibility\x12)\n\x05rules\x18\x01 \x03(\x0b\x32\x1a.google.api.VisibilityRule"7\n\x0eVisibilityRule\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x13\n\x0brestriction\x18\x02 \x01(\t:T\n\x0f\x65num_visibility\x12\x1c.google.protobuf.EnumOptions\x18\xaf\xca\xbc" \x01(\x0b\x32\x1a.google.api.VisibilityRule:Z\n\x10value_visibility\x12!.google.protobuf.EnumValueOptions\x18\xaf\xca\xbc" \x01(\x0b\x32\x1a.google.api.VisibilityRule:V\n\x10\x66ield_visibility\x12\x1d.google.protobuf.FieldOptions\x18\xaf\xca\xbc" \x01(\x0b\x32\x1a.google.api.VisibilityRule:Z\n\x12message_visibility\x12\x1f.google.protobuf.MessageOptions\x18\xaf\xca\xbc" \x01(\x0b\x32\x1a.google.api.VisibilityRule:X\n\x11method_visibility\x12\x1e.google.protobuf.MethodOptions\x18\xaf\xca\xbc" \x01(\x0b\x32\x1a.google.api.VisibilityRule:V\n\x0e\x61pi_visibility\x12\x1f.google.protobuf.ServiceOptions\x18\xaf\xca\xbc" \x01(\x0b\x32\x1a.google.api.VisibilityRuleBn\n\x0e\x63om.google.apiB\x0fVisibilityProtoP\x01Z?google.golang.org/genproto/googleapis/api/visibility;visibility\xf8\x01\x01\xa2\x02\x04GAPIb\x06proto3',
    dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR],
)


ENUM_VISIBILITY_FIELD_NUMBER = 72295727
enum_visibility = _descriptor.FieldDescriptor(
    name="enum_visibility",
    full_name="google.api.enum_visibility",
    index=0,
    number=72295727,
    type=11,
    cpp_type=10,
    label=1,
    has_default_value=False,
    default_value=None,
    message_type=None,
    enum_type=None,
    containing_type=None,
    is_extension=True,
    extension_scope=None,
    serialized_options=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
)
VALUE_VISIBILITY_FIELD_NUMBER = 72295727
value_visibility = _descriptor.FieldDescriptor(
    name="value_visibility",
    full_name="google.api.value_visibility",
    index=1,
    number=72295727,
    type=11,
    cpp_type=10,
    label=1,
    has_default_value=False,
    default_value=None,
    message_type=None,
    enum_type=None,
    containing_type=None,
    is_extension=True,
    extension_scope=None,
    serialized_options=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
)
FIELD_VISIBILITY_FIELD_NUMBER = 72295727
field_visibility = _descriptor.FieldDescriptor(
    name="field_visibility",
    full_name="google.api.field_visibility",
    index=2,
    number=72295727,
    type=11,
    cpp_type=10,
    label=1,
    has_default_value=False,
    default_value=None,
    message_type=None,
    enum_type=None,
    containing_type=None,
    is_extension=True,
    extension_scope=None,
    serialized_options=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
)
MESSAGE_VISIBILITY_FIELD_NUMBER = 72295727
message_visibility = _descriptor.FieldDescriptor(
    name="message_visibility",
    full_name="google.api.message_visibility",
    index=3,
    number=72295727,
    type=11,
    cpp_type=10,
    label=1,
    has_default_value=False,
    default_value=None,
    message_type=None,
    enum_type=None,
    containing_type=None,
    is_extension=True,
    extension_scope=None,
    serialized_options=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
)
METHOD_VISIBILITY_FIELD_NUMBER = 72295727
method_visibility = _descriptor.FieldDescriptor(
    name="method_visibility",
    full_name="google.api.method_visibility",
    index=4,
    number=72295727,
    type=11,
    cpp_type=10,
    label=1,
    has_default_value=False,
    default_value=None,
    message_type=None,
    enum_type=None,
    containing_type=None,
    is_extension=True,
    extension_scope=None,
    serialized_options=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
)
API_VISIBILITY_FIELD_NUMBER = 72295727
api_visibility = _descriptor.FieldDescriptor(
    name="api_visibility",
    full_name="google.api.api_visibility",
    index=5,
    number=72295727,
    type=11,
    cpp_type=10,
    label=1,
    has_default_value=False,
    default_value=None,
    message_type=None,
    enum_type=None,
    containing_type=None,
    is_extension=True,
    extension_scope=None,
    serialized_options=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
)


_VISIBILITY = _descriptor.Descriptor(
    name="Visibility",
    full_name="google.api.Visibility",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="rules",
            full_name="google.api.Visibility.rules",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=77,
    serialized_end=132,
)


_VISIBILITYRULE = _descriptor.Descriptor(
    name="VisibilityRule",
    full_name="google.api.VisibilityRule",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="selector",
            full_name="google.api.VisibilityRule.selector",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="restriction",
            full_name="google.api.VisibilityRule.restriction",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=134,
    serialized_end=189,
)

_VISIBILITY.fields_by_name["rules"].message_type = _VISIBILITYRULE
DESCRIPTOR.message_types_by_name["Visibility"] = _VISIBILITY
DESCRIPTOR.message_types_by_name["VisibilityRule"] = _VISIBILITYRULE
DESCRIPTOR.extensions_by_name["enum_visibility"] = enum_visibility
DESCRIPTOR.extensions_by_name["value_visibility"] = value_visibility
DESCRIPTOR.extensions_by_name["field_visibility"] = field_visibility
DESCRIPTOR.extensions_by_name["message_visibility"] = message_visibility
DESCRIPTOR.extensions_by_name["method_visibility"] = method_visibility
DESCRIPTOR.extensions_by_name["api_visibility"] = api_visibility
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Visibility = _reflection.GeneratedProtocolMessageType(
    "Visibility",
    (_message.Message,),
    {
        "DESCRIPTOR": _VISIBILITY,
        "__module__": "google.api.visibility_pb2"
        # @@protoc_insertion_point(class_scope:google.api.Visibility)
    },
)
_sym_db.RegisterMessage(Visibility)

VisibilityRule = _reflection.GeneratedProtocolMessageType(
    "VisibilityRule",
    (_message.Message,),
    {
        "DESCRIPTOR": _VISIBILITYRULE,
        "__module__": "google.api.visibility_pb2"
        # @@protoc_insertion_point(class_scope:google.api.VisibilityRule)
    },
)
_sym_db.RegisterMessage(VisibilityRule)

enum_visibility.message_type = _VISIBILITYRULE
google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(enum_visibility)
value_visibility.message_type = _VISIBILITYRULE
google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(
    value_visibility
)
field_visibility.message_type = _VISIBILITYRULE
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(field_visibility)
message_visibility.message_type = _VISIBILITYRULE
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(
    message_visibility
)
method_visibility.message_type = _VISIBILITYRULE
google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(
    method_visibility
)
api_visibility.message_type = _VISIBILITYRULE
google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(api_visibility)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
